/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef BALLPLUGIN_H
#define BALLPLUGIN_H

#include <U2Core/PluginModel.h>

namespace U2
{

class BallPlugin : public Plugin
{
    Q_OBJECT
public:
    BallPlugin();
};

} // namespace

#endif // BALLPLUGIN_H
